#!/usr/bin/env python
from patroni.__main__ import main


if __name__ == '__main__':
    main()
